==> jc-unilever-domain-0.1.222-sources.jar: com/xforceplus/ultraman/app/jcunilever/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jcunilever.metadata;

/**
 *
 * @author ultraman
 * @since 2023-03-20
 */

public class PageMeta {
    public interface OrderPool {
        static String code() {
            return "orderPool";
        }
        static String name() {
            return "订单池";
        }
    }
    public interface SettlePool {
        static String code() {
            return "settlePool";
        }
        static String name() {
            return "结算池";
        }
    }
    public interface OrderSettlePool {
        static String code() {
            return "orderSettlePool";
        }
        static String name() {
            return "订单结算池";
        }
    }
    public interface BlobFiles {
        static String code() {
            return "blobFiles";
        }
        static String name() {
            return "Blob文件管理";
        }
    }
    public interface Producer {
        static String code() {
            return "producer";
        }
        static String name() {
            return "定时待办运维";
        }
    }
    public interface BusinessUnitConfig {
        static String code() {
            return "businessUnitConfig";
        }
        static String name() {
            return "业务部门配置";
        }
    }
    public interface DiscountReasonConfig {
        static String code() {
            return "discountReasonConfig";
        }
        static String name() {
            return "折扣原因配置";
        }
    }
    public interface NoInvoicedReasonConfig {
        static String code() {
            return "noInvoicedReasonConfig";
        }
        static String name() {
            return "不开票原因配置";
        }
    }
    public interface MdmDevOps {
        static String code() {
            return "mdmDevOps";
        }
        static String name() {
            return "MDM管理";
        }
    }
    public interface RawDataOps {
        static String code() {
            return "rawDataOps";
        }
        static String name() {
            return "原始数据运维";
        }
    }
    public interface Emailmanagement {
        static String code() {
            return "emailmanagement";
        }
        static String name() {
            return "邮件待办运维";
        }
    }
    public interface InvoiceOperation {
        static String code() {
            return "invoiceOperation";
        }
        static String name() {
            return "发票回传运维";
        }
    }
    public interface TodoTaskPage {
        static String code() {
            return "todoTaskPage";
        }
        static String name() {
            return "待办任务管理页面";
        }
    }
}

==> jc-unilever-domain-0.1.542-sources.jar: com/xforceplus/ultraman/app/jcunilever/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jcunilever.metadata;

/**
 *
 * @author ultraman
 * @since 2023-07-11
 */

public class PageMeta {
    public interface SettlePool {
        static String code() {
            return "settlePool";
        }
        static String name() {
            return "结算池";
        }
    }
    public interface OrderSettlePool {
        static String code() {
            return "orderSettlePool";
        }
        static String name() {
            return "订单结算池";
        }
    }
    public interface BlobFiles {
        static String code() {
            return "blobFiles";
        }
        static String name() {
            return "Blob文件管理";
        }
    }
    public interface Producer {
        static String code() {
            return "producer";
        }
        static String name() {
            return "定时待办运维";
        }
    }
    public interface BusinessUnitConfig {
        static String code() {
            return "businessUnitConfig";
        }
        static String name() {
            return "业务部门配置";
        }
    }
    public interface DiscountReasonConfig {
        static String code() {
            return "discountReasonConfig";
        }
        static String name() {
            return "折扣原因配置";
        }
    }
    public interface NoInvoicedReasonConfig {
        static String code() {
            return "noInvoicedReasonConfig";
        }
        static String name() {
            return "不开票原因配置";
        }
    }
    public interface MdmDevOps {
        static String code() {
            return "mdmDevOps";
        }
        static String name() {
            return "MDM管理";
        }
    }
    public interface RawDataOps {
        static String code() {
            return "rawDataOps";
        }
        static String name() {
            return "原始数据运维";
        }
    }
    public interface Emailmanagement {
        static String code() {
            return "emailmanagement";
        }
        static String name() {
            return "邮件待办运维";
        }
    }
    public interface InvoiceOperation {
        static String code() {
            return "invoiceOperation";
        }
        static String name() {
            return "发票回传运维";
        }
    }
    public interface TodoTaskPage {
        static String code() {
            return "todoTaskPage";
        }
        static String name() {
            return "待办任务管理页面";
        }
    }
    public interface InvoiceDiscountOps {
        static String code() {
            return "invoiceDiscountOps";
        }
        static String name() {
            return "发票折扣清单";
        }
    }
    public interface BillingAdmin {
        static String code() {
            return "billingAdmin";
        }
        static String name() {
            return "Billing单管理";
        }
    }
    public interface BillingTypeWriteOffConfig {
        static String code() {
            return "billingTypeWriteOffConfig";
        }
        static String name() {
            return "Billing冲销类型配置";
        }
    }
}
